diff --git a/src/pages/org/DepartmentsPage.tsx b/src/pages/org/DepartmentsPage.tsx
index 72b5eef..b0cdc94 100644
--- a/src/pages/org/DepartmentsPage.tsx
+++ b/src/pages/org/DepartmentsPage.tsx
@@ -658,9 +658,6 @@ export default function DepartmentsPage() {
})
)}
-
- Created {new Date(dept.created_at).toLocaleDateString()}
-
{/* Members toggle */}
diff --git a/src/lib/api.ts b/src/lib/api.ts
index 18c6083..05205cc 100644
--- a/src/lib/api.ts
+++ b/src/lib/api.ts
@@ -814,9 +814,12 @@ export const api = {
getById: (orgId: string, requestConfig?: RequestConfig) =>
request<{ organization: Organization; member_count: number }>(`/organizations/${orgId}`, {}, true, requestConfig),
- // Delete an organization (owner only; must have no other members)
- deleteOrganization: (orgId: string, requestConfig?: RequestConfig) =>
- request<{ message: string }>(`/organizations/${orgId}`, { method: 'DELETE' }, true, requestConfig),
+ // Delete an organization (owner only; pass confirm=true when other members exist)
+ deleteOrganization: (orgId: string, confirm?: boolean, requestConfig?: RequestConfig) =>
+ request<{ message: string }>(`/organizations/${orgId}`, {
+ method: 'DELETE',
+ ...(confirm ? { body: JSON.stringify({ confirm: true }) } : {}),
+ }, true, requestConfig),
// Get organization members
getMembers: (orgId: string, requestConfig?: RequestConfig) =>